from enum import Enum


class ColumnType(str, Enum):
    TEXT = 'text'
    CHOICE = 'choice'
    NUMBER = 'number'
    DECIMAL_1 = 'decimal_1'
    DECIMAL_2 = 'decimal_2'
    DECIMAL_3 = 'decimal_3'
    DOLLAR = 'dollar'
    PERCENT = 'percent'





from django_spire.metric.report.enums import ColumnType


def get_text_alignment_css_class(column_type: ColumnType) -> str:
    if column_type in (ColumnType.DOLLAR, ColumnType.NUMBER, ColumnType.PERCENT, ColumnType.DECIMAL_1,
                     ColumnType.DECIMAL_2, ColumnType.DECIMAL_3):
        return 'text-end'
    if column_type == ColumnType.CHOICE:
        return 'text-center'

    return 'text-start'
